rpms/kdelibs/devel kdelibs-4.1.70-cmake.patch, NONE, 1.1 kdelibs-4.1.72-kstandarddirs.patch, NONE, 1.1 kdelibs-4.1.72-no-cache-kdeglobals-paths.patch, NONE, 1.1 kdelibs-4.1.72-parallel_devel.patch, NONE, 1.1 kdelibs-4.1.72-policykit-workaround.patch, NONE, 1.1 .cvsignore, 1.60, 1.61 kdelibs.spec, 1.389, 1.390 sources, 1.72, 1.73 kdelibs-4.0.2-no-cache-kdeglobals-paths.patch, 1.1, NONE kdelibs-4.1.0-kstandarddirs.patch, 1.1, NONE kdelibs-4.1.1-cmake.patch, 1.4, NONE kdelibs-4.1.69-parallel_devel.patch, 1.1, NONE kdelibs-4.1.69-policykit-workaround.patch, 1.1, NONE

Than Ngo than at fedoraproject.org
Thu Nov 20 10:23:21 UTC 2008


Author: than

Update of /cvs/extras/rpms/kdelibs/devel
In directory cvs1.fedora.phx.redhat.com:/tmp/cvs-serv12894

Modified Files:
	.cvsignore kdelibs.spec sources 
Added Files:
	kdelibs-4.1.70-cmake.patch kdelibs-4.1.72-kstandarddirs.patch 
	kdelibs-4.1.72-no-cache-kdeglobals-paths.patch 
	kdelibs-4.1.72-parallel_devel.patch 
	kdelibs-4.1.72-policykit-workaround.patch 
Removed Files:
	kdelibs-4.0.2-no-cache-kdeglobals-paths.patch 
	kdelibs-4.1.0-kstandarddirs.patch kdelibs-4.1.1-cmake.patch 
	kdelibs-4.1.69-parallel_devel.patch 
	kdelibs-4.1.69-policykit-workaround.patch 
Log Message:
kde-4.2 beta1


kdelibs-4.1.70-cmake.patch:

--- NEW FILE kdelibs-4.1.70-cmake.patch ---
diff -Naur kdelibs-4.1.70/cmake/modules/FindKDE4Internal.cmake kdelibs-4.1.70.cmake/cmake/modules/FindKDE4Internal.cmake
--- kdelibs-4.1.70/cmake/modules/FindKDE4Internal.cmake	2008-10-19 16:56:45.000000000 +0200
+++ kdelibs-4.1.70.cmake/cmake/modules/FindKDE4Internal.cmake	2008-10-19 17:06:14.000000000 +0200
@@ -817,6 +817,7 @@
 # CMake generators if no build type is set.
 if (NOT CMAKE_CONFIGURATION_TYPES AND NOT CMAKE_BUILD_TYPE)
    set(CMAKE_BUILD_TYPE RelWithDebInfo)
+   set(CMAKE_CONFIGURATION_TYPES ${CMAKE_BUILD_TYPE})
 endif (NOT CMAKE_CONFIGURATION_TYPES AND NOT CMAKE_BUILD_TYPE)
 
 

kdelibs-4.1.72-kstandarddirs.patch:

--- NEW FILE kdelibs-4.1.72-kstandarddirs.patch ---
diff -Naur kdelibs-4.1.72/kdecore/kernel/kstandarddirs.cpp kdelibs-4.1.72.kstandarddirs/kdecore/kernel/kstandarddirs.cpp
--- kdelibs-4.1.72/kdecore/kernel/kstandarddirs.cpp	2008-11-12 18:31:44.000000000 +0100
+++ kdelibs-4.1.72.kstandarddirs/kdecore/kernel/kstandarddirs.cpp	2008-11-12 18:38:40.000000000 +0100
@@ -1002,7 +1002,9 @@
                  pit != prefixList->end();
                  ++pit)
             {
-	        if((*pit)!=installprefix||installdir.isEmpty())
+                // "exe" never has a custom install path, and the check triggers
+                // a false positive due to the libexecdir patch
+	        if((*pit)!=installprefix||installdir.isEmpty()||!strcmp("exe", type))
 	        {
                     for (QStringList::ConstIterator it = dirs.constBegin();
                          it != dirs.constEnd(); ++it)
@@ -1016,6 +1018,11 @@
                         if ((local || testdir.exists()) && !candidates.contains(path))
                             candidates.append(path);
                     }
+                    // special-case "config" (forward porting Chris Cheney's
+                    // hack) - we want /etc/kde after the local config paths
+                    // and before the ones in /usr (including kde-profile)
+                    if (local && !strcmp("config", type))
+                       candidates.append("/etc/kde/");
                     local = false;
                 }
 	        else

kdelibs-4.1.72-no-cache-kdeglobals-paths.patch:

--- NEW FILE kdelibs-4.1.72-no-cache-kdeglobals-paths.patch ---
diff -Naur kdelibs-4.1.72/kdecore/config/kconfig.cpp kdelibs-4.1.72.no-cache-kdeglobals-path/kdecore/config/kconfig.cpp
--- kdelibs-4.1.72/kdecore/config/kconfig.cpp	2008-10-23 01:05:09.000000000 +0200
+++ kdelibs-4.1.72.no-cache-kdeglobals-path/kdecore/config/kconfig.cpp	2008-11-10 17:38:33.000000000 +0100
@@ -61,12 +61,6 @@
 {
     sGlobalFileName = componentData.dirs()->saveLocation("config") +
                           QString::fromLatin1("kdeglobals");
-    if (wantGlobals()) {
-        const KStandardDirs *const dirs = componentData.dirs();
-        foreach(const QString& dir, dirs->findAllResources("config", QLatin1String("kdeglobals")) +
-                                    dirs->findAllResources("config", QLatin1String("system.kdeglobals")))
-            globalFiles.push_front(dir);
-    }
     const QString etc_kderc =
 #ifdef Q_WS_WIN
         QFile::decodeName( qgetenv("WINDIR") + "/kde4rc" );
@@ -76,15 +70,11 @@
     KEntryMap tmp;
     // first entry is always /etc/kderc or empty if cannot read
     if (KStandardDirs::checkAccess(etc_kderc, R_OK)) {
-        if (!globalFiles.contains(etc_kderc))
-            globalFiles.push_front(etc_kderc);
-
         if (!mappingsRegistered) {
             KSharedPtr<KConfigBackend> backend = KConfigBackend::create(componentData, etc_kderc, QLatin1String("INI"));
             backend->parseConfig( "en_US", tmp, KConfigBackend::ParseDefaults);
         }
     } else {
-        globalFiles.push_front(QString());
         mappingsRegistered = true;
     }
 
@@ -461,10 +451,31 @@
 
 void KConfigPrivate::parseGlobalFiles()
 {
+    QStringList globalFiles;
+
+    if (wantGlobals()) {
+        const KStandardDirs *const dirs = componentData.dirs();
+        foreach(const QString& dir, dirs->findAllResources("config", QLatin1String("kdeglobals")) +
+                                    dirs->findAllResources("config", QLatin1String("system.kdeglobals")))
+            globalFiles.push_front(dir);
+    }
+    const QString etc_kderc =
+#ifdef Q_WS_WIN
+        QFile::decodeName( QByteArray(::getenv("WINDIR")) + "\\kde4rc" );
+#else
+        QLatin1String("/etc/kde4rc");
+#endif
+    KEntryMap tmp;
+    // first entry is always /etc/kderc or empty if cannot read
+    if (KStandardDirs::checkAccess(etc_kderc, R_OK)) {
+        if (!globalFiles.contains(etc_kderc))
+            globalFiles.push_front(etc_kderc);
+    } else {
+        globalFiles.push_front(QString());
+    }
+
 //    qDebug() << "parsing global files" << globalFiles;
 
-    // TODO: can we cache the values in etc_kderc / other global files
-    //       on a per-application basis?
     const QByteArray utf8Locale = locale.toUtf8();
     foreach(const QString& file, globalFiles) {
         KConfigBackend::ParseOptions parseOpts = KConfigBackend::ParseGlobal|KConfigBackend::ParseExpansions;
diff -Naur kdelibs-4.1.72/kdecore/config/kconfig_p.h kdelibs-4.1.72.no-cache-kdeglobals-path/kdecore/config/kconfig_p.h
--- kdelibs-4.1.72/kdecore/config/kconfig_p.h	2008-06-03 11:34:54.000000000 +0200
+++ kdelibs-4.1.72.no-cache-kdeglobals-path/kdecore/config/kconfig_p.h	2008-11-10 17:38:33.000000000 +0100
@@ -86,7 +86,6 @@
 
     KEntryMap entryMap;
     QString backendType;
-    QStringList globalFiles;
     QStack<QString> extraFiles;
 
     QString locale;

kdelibs-4.1.72-parallel_devel.patch:

--- NEW FILE kdelibs-4.1.72-parallel_devel.patch ---
diff -Naur kdelibs-4.1.72/doc/api/doxygen-preprocess-kcfg.sh kdelibs-4.1.72.parallel_devel/doc/api/doxygen-preprocess-kcfg.sh
--- kdelibs-4.1.72/doc/api/doxygen-preprocess-kcfg.sh	2008-05-21 13:07:26.000000000 +0200
+++ kdelibs-4.1.72.parallel_devel/doc/api/doxygen-preprocess-kcfg.sh	2008-11-12 18:34:17.000000000 +0100
@@ -2,9 +2,9 @@
 # Generates and cleans KConfigXT source code during a API dox build
 #
 
-kcfg_compiler="`kde4-config --prefix`/bin/kconfig_compiler"
+kcfg_compiler="`kde4-config --prefix`/bin/kconfig_compiler4"
 if test -z "$kcfg_compiler"; then
-	echo "kconfig_compiler not found!"
+	echo "kconfig_compiler4 not found!"
 	exit 1;
 fi
 
diff -Naur kdelibs-4.1.72/kdecore/kconfig_compiler/checkkcfg.pl kdelibs-4.1.72.parallel_devel/kdecore/kconfig_compiler/checkkcfg.pl
--- kdelibs-4.1.72/kdecore/kconfig_compiler/checkkcfg.pl	2008-05-21 13:09:13.000000000 +0200
+++ kdelibs-4.1.72.parallel_devel/kdecore/kconfig_compiler/checkkcfg.pl	2008-11-12 18:34:17.000000000 +0100
@@ -15,12 +15,12 @@
 
 $kcfgc = $file . "c";
 
-$cmd = "./kconfig_compiler $file $kcfgc";
+$cmd = "./kconfig_compiler4 $file $kcfgc";
 
 #print "CMD $cmd\n";
 
 if ( system( $cmd ) != 0 ) {
-  print STDERR "Unable to run kconfig_compiler\n";
+  print STDERR "Unable to run kconfig_compiler4\n";
   exit 1;
 }
 
diff -Naur kdelibs-4.1.72/kdecore/kconfig_compiler/CMakeLists.txt kdelibs-4.1.72.parallel_devel/kdecore/kconfig_compiler/CMakeLists.txt
--- kdelibs-4.1.72/kdecore/kconfig_compiler/CMakeLists.txt	2008-10-30 15:19:14.000000000 +0100
+++ kdelibs-4.1.72.parallel_devel/kdecore/kconfig_compiler/CMakeLists.txt	2008-11-12 18:34:17.000000000 +0100
@@ -8,11 +8,11 @@
 set(kconfig_compiler_SRCS kconfig_compiler.cpp)
 
 
-kde4_add_executable(kconfig_compiler NOGUI RUN_UNINSTALLED ${kconfig_compiler_SRCS})
+kde4_add_executable(kconfig_compiler4 NOGUI RUN_UNINSTALLED ${kconfig_compiler_SRCS})
 
-target_link_libraries(kconfig_compiler  ${QT_QTCORE_LIBRARY} ${QT_QTXML_LIBRARY} )
+target_link_libraries(kconfig_compiler4  ${QT_QTCORE_LIBRARY} ${QT_QTXML_LIBRARY} )
 
-install(TARGETS kconfig_compiler ${INSTALL_TARGETS_DEFAULT_ARGS} )
+install(TARGETS kconfig_compiler4 ${INSTALL_TARGETS_DEFAULT_ARGS} )
 
 
 ########### install files ###############
diff -Naur kdelibs-4.1.72/kdeui/tests/kconfig_compiler/CMakeLists.txt kdelibs-4.1.72.parallel_devel/kdeui/tests/kconfig_compiler/CMakeLists.txt
--- kdelibs-4.1.72/kdeui/tests/kconfig_compiler/CMakeLists.txt	2008-05-21 13:08:30.000000000 +0200
+++ kdelibs-4.1.72.parallel_devel/kdeui/tests/kconfig_compiler/CMakeLists.txt	2008-11-12 18:34:17.000000000 +0100
@@ -9,7 +9,7 @@
    add_custom_command(
       OUTPUT ${CMAKE_CURRENT_BINARY_DIR}/${_testName}.cpp ${CMAKE_CURRENT_BINARY_DIR}/${_testName}.h
       COMMAND ${KDE4_KCFGC_EXECUTABLE} ${CMAKE_CURRENT_SOURCE_DIR}/${_testName}.kcfg ${CMAKE_CURRENT_SOURCE_DIR}/${_testName}.kcfgc
-      DEPENDS ${CMAKE_CURRENT_SOURCE_DIR}/${_testName}.kcfg ${CMAKE_CURRENT_SOURCE_DIR}/${_testName}.kcfgc kconfig_compiler)
+      DEPENDS ${CMAKE_CURRENT_SOURCE_DIR}/${_testName}.kcfg ${CMAKE_CURRENT_SOURCE_DIR}/${_testName}.kcfgc kconfig_compiler4)
 
 #   set_source_files_properties(${CMAKE_CURRENT_BINARY_DIR}/${_testName}.h PROPERTIES GENERATED TRUE)
    qt4_generate_moc(${CMAKE_CURRENT_BINARY_DIR}/${_testName}.h ${CMAKE_CURRENT_BINARY_DIR}/${_testName}.moc )
diff -Naur kdelibs-4.1.72/kdewidgets/CMakeLists.txt kdelibs-4.1.72.parallel_devel/kdewidgets/CMakeLists.txt
--- kdelibs-4.1.72/kdewidgets/CMakeLists.txt	2008-10-30 15:19:04.000000000 +0100
+++ kdelibs-4.1.72.parallel_devel/kdewidgets/CMakeLists.txt	2008-11-12 18:34:17.000000000 +0100
@@ -1,10 +1,10 @@
 
 project(kdewidgets)
 
-add_subdirectory( pics ) 
-add_subdirectory( tests ) 
+add_subdirectory( pics )
+add_subdirectory( tests )
 
-include_directories( 
+include_directories(
   ${KDE4_KIO_INCLUDES}
   ${CMAKE_SOURCE_DIR}/kde3support
   ${CMAKE_SOURCE_DIR}/kde3support/kdeui
@@ -16,22 +16,22 @@
 set(makekdewidgets_SRCS makekdewidgets.cpp )
 
 
-kde4_add_executable(makekdewidgets NOGUI RUN_UNINSTALLED ${makekdewidgets_SRCS})
+kde4_add_executable(makekdewidgets4 NOGUI RUN_UNINSTALLED ${makekdewidgets_SRCS})
 
-target_link_libraries(makekdewidgets  ${KDE4_KDECORE_LIBS} )
+target_link_libraries(makekdewidgets4  ${KDE4_KDECORE_LIBS} )
 
-install(TARGETS makekdewidgets ${INSTALL_TARGETS_DEFAULT_ARGS} )
+install(TARGETS makekdewidgets4 ${INSTALL_TARGETS_DEFAULT_ARGS} )
 
 
 ########### next target ###############
 
 
 # get the name of the generated wrapper script (which sets up LD_LIBRARY_PATH)
-get_target_property(MAKEKDEWIDGETS_EXECUTABLE makekdewidgets WRAPPER_SCRIPT)
+get_target_property(MAKEKDEWIDGETS_EXECUTABLE makekdewidgets4 WRAPPER_SCRIPT)
 
 add_custom_command(OUTPUT ${CMAKE_CURRENT_BINARY_DIR}/kdewidgets.cpp
   COMMAND "${MAKEKDEWIDGETS_EXECUTABLE}" -o ${CMAKE_CURRENT_BINARY_DIR}/kdewidgets.cpp ${CMAKE_CURRENT_SOURCE_DIR}/kde.widgets
-  MAIN_DEPENDENCY kde.widgets DEPENDS makekdewidgets)
+  MAIN_DEPENDENCY kde.widgets DEPENDS makekdewidgets4)
 
 set(kdewidgets_PART_SRCS
    classpreviews.cpp

kdelibs-4.1.72-policykit-workaround.patch:

--- NEW FILE kdelibs-4.1.72-policykit-workaround.patch ---
diff -Naur kdelibs-4.1.72.policykit/solid/solid/backends/hal/halstorageaccess.cpp kdelibs-4.1.72/solid/solid/backends/hal/halstorageaccess.cpp
--- kdelibs-4.1.72.policykit/solid/solid/backends/hal/halstorageaccess.cpp	2008-11-04 18:13:11.000000000 +0100
+++ kdelibs-4.1.72/solid/solid/backends/hal/halstorageaccess.cpp	2008-11-10 18:45:41.000000000 +0100
@@ -17,6 +17,8 @@
 
 */
 
+#include <config-prefix.h> // for LIBEXEC_INSTALL_DIR
+
 #include "halstorageaccess.h"
 
 #include "halfstabhandling.h"
@@ -172,11 +174,21 @@
 {
     // TODO: Better error reporting here
     if (m_setupInProgress) {
+	if (error.name() == "org.freedesktop.Hal.Device.PermissionDeniedByPolicy") {
+            if (callPrivilegedMount())
+              return;
+            // if we fail to run kdesu, fall through and emit the original PermissionDeniedByPolicy error
+        }
         m_setupInProgress = false;
         emit setupDone(Solid::UnauthorizedOperation,
                        error.name()+": "+error.message(),
                        m_device->udi());
     } else if (m_teardownInProgress) {
+	if (error.name() == "org.freedesktop.Hal.Device.PermissionDeniedByPolicy") {
+            if (callPrivilegedUnmount())
+              return;
+            // if we fail to run kdesu, fall through and emit the original PermissionDeniedByPolicy error
+        }
         m_teardownInProgress = false;
         emit teardownDone(Solid::UnauthorizedOperation,
                           error.name()+": "+error.message(),
@@ -294,8 +306,9 @@
 #else
     QString uid="uid=";
 #endif
-    if (halOptions.contains(uid)) {
-        options << uid+QString::number(::getuid());
+    if (halOptions.contains(uid) &&
+       (fstype == "vfat" || fstype == "iso9660" || fstype == "hfs" || fstype == "udf")) {
+            options << uid+QString::number(::getuid());
     }
 
 #ifdef Q_OS_FREEBSD
@@ -333,6 +346,59 @@
                               SLOT(slotDBusError(const QDBusError &)));
 }
 
+bool Solid::Backends::Hal::StorageAccess::callPrivilegedMount()
+{
+    QString udi = m_device->udi();
+    QString options;
+    QStringList halOptions = m_device->property("volume.mount.valid_options").toStringList();
+    QString fstype = m_device->property("volume.fstype").toString();
+
+    if (halOptions.contains("uid=")
+        && (fstype == "vfat" || fstype == "iso9660" || fstype == "hfs" || fstype == "udf")) {
+        options = "uid="+QString::number(::getuid());
+    }
+
+    m_process = new QProcess(this);
+
+    connect(m_process, SIGNAL(finished(int, QProcess::ExitStatus)),
+            this, SLOT(slotProcessFinished(int, QProcess::ExitStatus)));
+
+    m_process->start(LIBEXEC_INSTALL_DIR "/kdesu", QStringList() << "-d" << "-t"
+        << "--noignorebutton" << "-c"
+        << QString::fromLatin1("dbus-send  --system --print-reply --dest=org.freedesktop.Hal %1 "
+                               "org.freedesktop.Hal.Device.Volume.Mount string: string: "
+                               "array:string:%2").arg(udi).arg(options));
+
+    if (m_process->waitForStarted()) {
+        return true;
+    } else {
+        delete m_process;
+        return false;
+    }
+}
+
+bool Solid::Backends::Hal::StorageAccess::callPrivilegedUnmount()
+{
+    QString udi = m_device->udi();
+
+    m_process = new QProcess(this);
+
+    connect(m_process, SIGNAL(finished(int, QProcess::ExitStatus)),
+            this, SLOT(slotProcessFinished(int, QProcess::ExitStatus)));
+
+    m_process->start(LIBEXEC_INSTALL_DIR "/kdesu", QStringList() << "-d" << "-t"
+        << "--noignorebutton" << "-c"
+        << QString::fromLatin1("dbus-send  --system --print-reply --dest=org.freedesktop.Hal %1 "
+                               "org.freedesktop.Hal.Device.Volume.Unmount array:string:").arg(udi));
+
+    if (m_process->waitForStarted()) {
+        return true;
+    } else {
+        delete m_process;
+        return false;
+    }
+}
+
 bool StorageAccess::callHalVolumeUnmount()
 {
     QDBusConnection c = QDBusConnection::systemBus();
diff -Naur kdelibs-4.1.72.policykit/solid/solid/backends/hal/halstorageaccess.h kdelibs-4.1.72/solid/solid/backends/hal/halstorageaccess.h
--- kdelibs-4.1.72.policykit/solid/solid/backends/hal/halstorageaccess.h	2008-05-21 13:07:38.000000000 +0200
+++ kdelibs-4.1.72/solid/solid/backends/hal/halstorageaccess.h	2008-11-10 18:45:01.000000000 +0100
@@ -69,6 +69,9 @@
     bool callSystemMount();
     bool callSystemUnmount();
 
+    bool callPrivilegedMount();
+    bool callPrivilegedUnmount();
+
     bool requestPassphrase();
     void callCryptoSetup(const QString &passphrase);
     bool callCryptoTeardown();


Index: .cvsignore
===================================================================
RCS file: /cvs/extras/rpms/kdelibs/devel/.cvsignore,v
retrieving revision 1.60
retrieving revision 1.61
diff -u -r1.60 -r1.61
--- .cvsignore	17 Oct 2008 17:49:41 -0000	1.60
+++ .cvsignore	20 Nov 2008 10:22:49 -0000	1.61
@@ -1 +1,2 @@
 kdelibs-4.1.69.tar.bz2
+kdelibs-4.1.80.tar.bz2


Index: kdelibs.spec
===================================================================
RCS file: /cvs/extras/rpms/kdelibs/devel/kdelibs.spec,v
retrieving revision 1.389
retrieving revision 1.390
diff -u -r1.389 -r1.390
--- kdelibs.spec	17 Oct 2008 21:39:49 -0000	1.389
+++ kdelibs.spec	20 Nov 2008 10:22:50 -0000	1.390
@@ -1,8 +1,6 @@
-%define _default_patch_fuzz 2
-
 Summary: K Desktop Environment 4 - Libraries
-Version: 4.1.69
-Release: 1%{?dist}
+Version: 4.1.80
+Release: 2%{?dist}
 
 %if 0%{?fedora} > 8
 Name: kdelibs
@@ -32,9 +30,6 @@
 BuildRequires: kde-filesystem >= 4
 Requires: dbus-x11
 Requires: hicolor-icon-theme
-# kdebase-runtime not *strictly* required here, but how better to pull
-# it in?  comps only?
-#Requires: kdebase-runtime
 Requires: kde-filesystem >= 4
 Requires: kde-settings
 %{?_kde4_macros_api:Requires: kde4-macros(api) = %{_kde4_macros_api} }
@@ -51,7 +46,7 @@
 Source2: kde4.csh
 
 # make -devel packages parallel-installable
-Patch0: kdelibs-4.1.69-parallel_devel.patch
+Patch0: kdelibs-4.1.72-parallel_devel.patch
 # fix kde#149705
 Patch2: kdelibs-3.95.0-kde149705.patch
 # Hunspell support for K3Spell
@@ -67,15 +62,15 @@
 Patch9: kdelibs-4.0.2-branding.patch
 # don't cache kdeglobals paths because they change after profile directories
 # are loaded from kde4rc
-Patch10: kdelibs-4.0.2-no-cache-kdeglobals-paths.patch
+Patch10: kdelibs-4.1.72-no-cache-kdeglobals-paths.patch
 # workaround for policykit
-Patch11: kdelibs-4.1.69-policykit-workaround.patch
+Patch11: kdelibs-4.1.72-policykit-workaround.patch
 Patch12: kdelibs-4.1.0-xdg-menu.patch
 # patch KStandardDirs to use %{_libexecdir}/kde4 instead of %{_libdir}/kde4/libexec
 Patch14: kdelibs-4.0.85-libexecdir.patch
 # kstandarddirs changes: search /etc/kde, find /usr/libexec/kde4
-Patch18: kdelibs-4.1.0-kstandarddirs.patch
-Patch20: kdelibs-4.1.1-cmake.patch
+Patch18: kdelibs-4.1.72-kstandarddirs.patch
+Patch20: kdelibs-4.1.70-cmake.patch
 
 BuildRequires: qt4-devel >= 4.4.0
 Requires: qt4 >= %{_qt4_version}
@@ -91,7 +86,7 @@
 BuildRequires: automoc
 BuildRequires: avahi-devel
 BuildRequires: bzip2-devel
-BuildRequires: cmake >= 2.6
+BuildRequires: cmake >= 2.6.2
 BuildRequires: cups-devel cups
 BuildRequires: enchant-devel
 BuildRequires: gamin-devel
@@ -148,6 +143,7 @@
 Obsoletes: kdelibs4-devel < %{version}-%{release}
 Provides:  kdelibs4-devel = %{version}-%{release}
 %endif
+Requires: cmake >= 2.6.2
 Requires: automoc
 Requires: qt4-devel
 Requires: openssl-devel
@@ -194,7 +190,7 @@
 %patch9 -p1 -b .branding
 sed -i -e "s|@@VERSION_RELEASE@@|%{version}-%{release}|" kio/kio/kprotocolmanager.cpp
 %patch10 -p1 -b .no-cache-kdeglobals-paths
-%patch11 -p1 -b .policykit
+#%patch11 -p1 -b .policykit
 %patch12 -p1 -b .Administration-menu
 %patch14 -p1 -b .libexecdir
 %patch18 -p1 -b .kstandarddirs
@@ -246,8 +242,6 @@
   case "$i" in
     libkdeinit4_*.so)
       ;;
-    libkformulalib.so)
-      ;;
     ## FIXME/TODO: imo, should leave everything except for known-conflicts -- Rex
     *)
       linktarget=`readlink "$i"`
@@ -314,7 +308,6 @@
 %{_kde4_sharedir}/icons/hicolor/*/actions/*
 %{_kde4_docdir}/HTML/en/sonnet/
 %{_kde4_libdir}/lib*.so.*
-%{_kde4_libdir}/libkformulalib.so
 %{_kde4_libdir}/libkdeinit4_*.so
 %dir %{_kde4_libdir}/kde4/
 %{_kde4_libdir}/kde4/*.so
@@ -362,10 +355,23 @@
 
 
 %changelog
-* Sun Oct 17 2008 Lorenzo Villani <lvillani at binaryhelix.net> - 6:4.1.69-1
-- 4.1.69
-- BR cmake >= 2.6, strigi-devel >= 0.6.0
-- use make install/fast
+* Thu Nov 20 2008 Than Ngo <than at redhat.com> 4.1.80-2
+- merged
+
+* Thu Nov 20 2008 Lorenzo Villani <lvillani at binaryhelix.net> - 6:4.1.80-1
+- 4.1.80
+- BR strigi 0.60
+- BR cmake 2.6
+- make install/fast
+- rebase policykit patch
+- rebase cmake patch
+- rebase a couple of patches and drop _default_patch_fuzz 2
+
+* Wed Nov 12 2008 Than Ngo <than at redhat.com> 4.1.3-1
+- 4.1.3
+
+* Fri Nov 07 2008 Rex Dieter <rdieter at fedoraproject.org> 4.1.2-6
+- backport http_cache_cleaner fix (kdebug:172182)
 
 * Wed Oct 15 2008 Lukáš Tinkl <ltinkl at redhat.com> 4.1.2-5
 - backport fix for faulty window resizing (kdebug:172042)


Index: sources
===================================================================
RCS file: /cvs/extras/rpms/kdelibs/devel/sources,v
retrieving revision 1.72
retrieving revision 1.73
diff -u -r1.72 -r1.73
--- sources	17 Oct 2008 17:49:41 -0000	1.72
+++ sources	20 Nov 2008 10:22:50 -0000	1.73
@@ -1 +1 @@
-1a5b1834df6e782236ebd3294d8c7f2a  kdelibs-4.1.69.tar.bz2
+46673e485f296b8f3741c7394e6cbc52  kdelibs-4.1.80.tar.bz2


--- kdelibs-4.0.2-no-cache-kdeglobals-paths.patch DELETED ---


--- kdelibs-4.1.0-kstandarddirs.patch DELETED ---


--- kdelibs-4.1.1-cmake.patch DELETED ---


--- kdelibs-4.1.69-parallel_devel.patch DELETED ---


--- kdelibs-4.1.69-policykit-workaround.patch DELETED ---




More information about the scm-commits mailing list
diff -Naur kdelibs-4.1.72/cmake/modules/FindKDE4Internal.cmake kdelibs-4.1.72.parallel_devel/cmake/modules/FindKDE4Internal.cmake
--- kdelibs-4.1.72/cmake/modules/FindKDE4Internal.cmake	2008-11-12 18:31:44.000000000 +0100
+++ kdelibs-4.1.72.parallel_devel/cmake/modules/FindKDE4Internal.cmake	2008-11-12 18:35:47.000000000 +0100
@@ -15,10 +15,10 @@
 # The following variables are defined for the various tools required to
 # compile KDE software:
 #
-#  KDE4_KCFGC_EXECUTABLE    - the kconfig_compiler executable
+#  KDE4_KCFGC_EXECUTABLE    - the kconfig_compiler4 executable
 #  KDE4_AUTOMOC_EXECUTABLE  - the kde4automoc executable, deprecated, use AUTOMOC4_EXECUTABLE instead
 #  KDE4_MEINPROC_EXECUTABLE - the meinproc4 executable
-#  KDE4_MAKEKDEWIDGETS_EXECUTABLE - the makekdewidgets executable
+#  KDE4_MAKEKDEWIDGETS_EXECUTABLE - the makekdewidgets4 executable
 #
 # The following variables point to the location of the KDE libraries,
 # but shouldn't be used directly:
@@ -76,7 +76,7 @@
 #  KDE4_KFORMULA_LIBS         - the kformula library and all depending librairies
 #  KDE4_PLASMA_LIBS           - the plasma library and all depending librairies
 #
-# This module defines a bunch of variables used as locations for install directories. 
+# This module defines a bunch of variables used as locations for install directories.
 # They can be relative (to CMAKE_INSTALL_PREFIX) or absolute.
 # Under Windows they are always relative.
 #
@@ -128,7 +128,7 @@
 #    Use optional GENERATE_MOC to generate moc if you use signals in your kcfg files.
 #
 #  KDE4_ADD_WIDGET_FILES (SRCS_VAR file1.widgets ... fileN.widgets)
 #    Use this to add widget description files for the makekdewidgets code generator
 #    for Qt Designer plugins.
 #
 #  KDE4_CREATE_FINAL_FILES (filename_CXX filename_C file1 ... fileN)
@@ -299,9 +299,9 @@
 find_package(Perl ${_REQ_STRING_KDE4})
 
 # Check that we really found everything.
-# If KDE4 was searched with REQUIRED, we error out with FATAL_ERROR if something wasn't found 
+# If KDE4 was searched with REQUIRED, we error out with FATAL_ERROR if something wasn't found
 # already above in the other FIND_PACKAGE() calls.
-# If KDE4 was searched without REQUIRED and something in the FIND_PACKAGE() calls above wasn't found, 
+# If KDE4 was searched without REQUIRED and something in the FIND_PACKAGE() calls above wasn't found,
 # then we get here and must check that everything has actually been found. If something is missing,
 # we must not fail with FATAL_ERROR, but only not set KDE4_FOUND.
 if(NOT PERL_FOUND)
@@ -369,23 +369,23 @@
    if (WIN32)
       set(LIBRARY_OUTPUT_PATH            ${EXECUTABLE_OUTPUT_PATH} )
       # CMAKE_CFG_INTDIR is the output subdirectory created e.g. by XCode and MSVC
-      set(KDE4_KCFGC_EXECUTABLE          ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/kconfig_compiler )
+      set(KDE4_KCFGC_EXECUTABLE          ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/kconfig_compiler4 )
 
       set(KDE4_MEINPROC_EXECUTABLE       ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/meinproc4 )
-      set(KDE4_MAKEKDEWIDGETS_EXECUTABLE ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/makekdewidgets )
+      set(KDE4_MAKEKDEWIDGETS_EXECUTABLE ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/makekdewidgets4 )
    else (WIN32)
       set(LIBRARY_OUTPUT_PATH            ${CMAKE_BINARY_DIR}/lib )
-      set(KDE4_KCFGC_EXECUTABLE          ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/kconfig_compiler.shell )
+      set(KDE4_KCFGC_EXECUTABLE          ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/kconfig_compiler4.shell )
 
       set(KDE4_MEINPROC_EXECUTABLE       ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/meinproc4.shell )
-      set(KDE4_MAKEKDEWIDGETS_EXECUTABLE ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/makekdewidgets.shell )
+      set(KDE4_MAKEKDEWIDGETS_EXECUTABLE ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/makekdewidgets4.shell )
    endif (WIN32)
 
    set(KDE4_LIB_DIR ${LIBRARY_OUTPUT_PATH}/${CMAKE_CFG_INTDIR})
 
    # when building kdelibs, make the kcfg rules depend on the binaries...
-   set( _KDE4_KCONFIG_COMPILER_DEP kconfig_compiler)
-   set( _KDE4_MAKEKDEWIDGETS_DEP makekdewidgets)
+   set( _KDE4_KCONFIG_COMPILER_DEP kconfig_compiler4)
+   set( _KDE4_MAKEKDEWIDGETS_DEP makekdewidgets4)
    set( _KDE4_MEINPROC_EXECUTABLE_DEP meinproc4)
 
    set(KDE4_INSTALLED_VERSION_OK TRUE)
@@ -435,11 +435,11 @@
    set(LIBRARY_OUTPUT_PATH  ${CMAKE_BINARY_DIR}/lib )
 
    if (WIN32)
-      # we don't want to be forced to set two paths into the build tree 
+      # we don't want to be forced to set two paths into the build tree
       set(LIBRARY_OUTPUT_PATH  ${CMAKE_BINARY_DIR}/bin )
 
       # on win32 the install dir is determined on runtime not install time
-      # KDELIBS_INSTALL_DIR and QT_INSTALL_DIR are used in KDELibsDependencies.cmake to setup 
+      # KDELIBS_INSTALL_DIR and QT_INSTALL_DIR are used in KDELibsDependencies.cmake to setup
       # kde install paths and library dependencies
       get_filename_component(_DIR ${KDE4_KDECONFIG_EXECUTABLE} PATH )
       get_filename_component(KDE4_INSTALL_DIR ${_DIR} PATH )
@@ -451,69 +451,69 @@
    include(${kde_cmake_module_dir}/KDELibsDependencies.cmake)
 
    if (UNIX)
-      find_library(KDE4_KDEFAKES_LIBRARY NAMES kdefakes PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
+      find_library(KDE4_KDEFAKES_LIBRARY NAMES kdefakes PATHS ${KDE4_LIB_INSTALL_DIR}/kde4/devel NO_DEFAULT_PATH )
       set(KDE4_KDEFAKES_LIBS ${kdefakes_LIB_DEPENDS} ${KDE4_KDEFAKES_LIBRARY} )
    endif (UNIX)
 
-   find_library(KDE4_KDECORE_LIBRARY NAMES kdecore PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
+   find_library(KDE4_KDECORE_LIBRARY NAMES kdecore PATHS ${KDE4_LIB_INSTALL_DIR}/kde4/devel NO_DEFAULT_PATH )
    set(KDE4_KDECORE_LIBS ${kdecore_LIB_DEPENDS} ${KDE4_KDECORE_LIBRARY} )
 
-   find_library(KDE4_KDEUI_LIBRARY NAMES kdeui PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
+   find_library(KDE4_KDEUI_LIBRARY NAMES kdeui PATHS ${KDE4_LIB_INSTALL_DIR}/kde4/devel NO_DEFAULT_PATH )
    set(KDE4_KDEUI_LIBS ${kdeui_LIB_DEPENDS} ${KDE4_KDEUI_LIBRARY} )
-   find_library(KDE4_KIO_LIBRARY NAMES kio PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
+   find_library(KDE4_KIO_LIBRARY NAMES kio PATHS ${KDE4_LIB_INSTALL_DIR}/kde4/devel NO_DEFAULT_PATH )
    set(KDE4_KIO_LIBS ${kio_LIB_DEPENDS} ${KDE4_KIO_LIBRARY} )
 
-   find_library(KDE4_KPARTS_LIBRARY NAMES kparts PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
+   find_library(KDE4_KPARTS_LIBRARY NAMES kparts PATHS ${KDE4_LIB_INSTALL_DIR}/kde4/devel NO_DEFAULT_PATH )
    set(KDE4_KPARTS_LIBS ${kparts_LIB_DEPENDS} ${KDE4_KPARTS_LIBRARY} )
 
-   find_library(KDE4_KUTILS_LIBRARY NAMES kutils PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
+   find_library(KDE4_KUTILS_LIBRARY NAMES kutils PATHS ${KDE4_LIB_INSTALL_DIR}/kde4/devel NO_DEFAULT_PATH )
    set(KDE4_KUTILS_LIBS ${kutils_LIB_DEPENDS} ${KDE4_KUTILS_LIBRARY} )
 
-   find_library(KDE4_KDE3SUPPORT_LIBRARY NAMES kde3support PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
+   find_library(KDE4_KDE3SUPPORT_LIBRARY NAMES kde3support PATHS ${KDE4_LIB_INSTALL_DIR}/kde4/devel NO_DEFAULT_PATH )
    set(KDE4_KDE3SUPPORT_LIBS ${kde3support_LIB_DEPENDS} ${KDE4_KDE3SUPPORT_LIBRARY} )
 
-   find_library(KDE4_KFILE_LIBRARY NAMES kfile PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
+   find_library(KDE4_KFILE_LIBRARY NAMES kfile PATHS ${KDE4_LIB_INSTALL_DIR}/kde4/devel NO_DEFAULT_PATH )
    set(KDE4_KFILE_LIBS ${kfile_LIB_DEPENDS} ${KDE4_KFILE_LIBRARY} )
 
-   find_library(KDE4_KHTML_LIBRARY NAMES khtml PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
+   find_library(KDE4_KHTML_LIBRARY NAMES khtml PATHS ${KDE4_LIB_INSTALL_DIR}/kde4/devel NO_DEFAULT_PATH )
    set(KDE4_KHTML_LIBS ${khtml_LIB_DEPENDS} ${KDE4_KHTML_LIBRARY} )
 
-   find_library(KDE4_KJS_LIBRARY NAMES kjs PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
+   find_library(KDE4_KJS_LIBRARY NAMES kjs PATHS ${KDE4_LIB_INSTALL_DIR}/kde4/devel NO_DEFAULT_PATH )
    set(KDE4_KJS_LIBS ${kjs_LIB_DEPENDS} ${KDE4_KJS_LIBRARY} )
 
-   find_library(KDE4_KJSAPI_LIBRARY NAMES kjsapi PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
+   find_library(KDE4_KJSAPI_LIBRARY NAMES kjsapi PATHS ${KDE4_LIB_INSTALL_DIR}/kde4/devel NO_DEFAULT_PATH )
    set(KDE4_KJSAPI_LIBS ${kjsapi_LIB_DEPENDS} ${KDE4_KJSAPI_LIBRARY} )
 
-   find_library(KDE4_KNEWSTUFF2_LIBRARY NAMES knewstuff2 PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
+   find_library(KDE4_KNEWSTUFF2_LIBRARY NAMES knewstuff2 PATHS ${KDE4_LIB_INSTALL_DIR}/kde4/devel NO_DEFAULT_PATH )
    set(KDE4_KNEWSTUFF2_LIBS ${knewstuff2_LIB_DEPENDS} ${KDE4_KNEWSTUFF2_LIBRARY} )
 
    if (UNIX)
-      find_library(KDE4_KPTY_LIBRARY NAMES kpty PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
+      find_library(KDE4_KPTY_LIBRARY NAMES kpty PATHS ${KDE4_LIB_INSTALL_DIR}/kde4/devel NO_DEFAULT_PATH )
       set(KDE4_KPTY_LIBS ${kpty_LIB_DEPENDS} ${KDE4_KPTY_LIBRARY} )
 
-      find_library(KDE4_KDESU_LIBRARY NAMES kdesu PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
+      find_library(KDE4_KDESU_LIBRARY NAMES kdesu PATHS ${KDE4_LIB_INSTALL_DIR}/kde4/devel NO_DEFAULT_PATH )
       set(KDE4_KDESU_LIBS ${kdesu_LIB_DEPENDS} ${KDE4_KDESU_LIBRARY} )
    endif (UNIX)
 
-   find_library(KDE4_KDNSSD_LIBRARY NAMES kdnssd PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
+   find_library(KDE4_KDNSSD_LIBRARY NAMES kdnssd PATHS ${KDE4_LIB_INSTALL_DIR}/kde4/devel NO_DEFAULT_PATH )
    set(KDE4_KDNSSD_LIBS ${kdnssd_LIB_DEPENDS} ${KDE4_KDNSSD_LIBRARY} )
 
-   find_library(KDE4_SOLID_LIBRARY NAMES solid PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
+   find_library(KDE4_SOLID_LIBRARY NAMES solid PATHS ${KDE4_LIB_INSTALL_DIR}/kde4/devel NO_DEFAULT_PATH )
    set(KDE4_SOLID_LIBS ${solid_LIB_DEPENDS} ${KDE4_SOLID_LIBRARY} )
 
-   find_library(KDE4_THREADWEAVER_LIBRARY NAMES threadweaver PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
+   find_library(KDE4_THREADWEAVER_LIBRARY NAMES threadweaver PATHS ${KDE4_LIB_INSTALL_DIR}/kde4/devel NO_DEFAULT_PATH )
    set(KDE4_THREADWEAVER_LIBRARIES ${threadweaver_LIB_DEPENDS} ${KDE4_THREADWEAVER_LIBRARY} )
 
-   find_library(KDE4_KNOTIFYCONFIG_LIBRARY NAMES knotifyconfig PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
+   find_library(KDE4_KNOTIFYCONFIG_LIBRARY NAMES knotifyconfig PATHS ${KDE4_LIB_INSTALL_DIR}/kde4/devel NO_DEFAULT_PATH )
    set(KDE4_KNOTIFYCONFIG_LIBS ${knotifyconfig_LIB_DEPENDS} ${KDE4_KNOTIFYCONFIG_LIBRARY} )
 
-   find_library(KDE4_KROSSCORE_LIBRARY NAMES krosscore PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
+   find_library(KDE4_KROSSCORE_LIBRARY NAMES krosscore PATHS ${KDE4_LIB_INSTALL_DIR}/kde4/devel NO_DEFAULT_PATH )
    set(KDE4_KROSSCORE_LIBS ${krosscore_LIB_DEPENDS} ${KDE4_KROSSCORE_LIBRARY} )
 
-   find_library(KDE4_KROSSUI_LIBRARY NAMES krossui PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
+   find_library(KDE4_KROSSUI_LIBRARY NAMES krossui PATHS ${KDE4_LIB_INSTALL_DIR}/kde4/devel NO_DEFAULT_PATH )
    set(KDE4_KROSSUI_LIBS ${krossui_LIB_DEPENDS} ${KDE4_KROSSCORE_LIBS} ${KDE4_KROSSUI_LIBRARY} )
 
-   find_library(KDE4_KTEXTEDITOR_LIBRARY NAMES ktexteditor PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
+   find_library(KDE4_KTEXTEDITOR_LIBRARY NAMES ktexteditor PATHS ${KDE4_LIB_INSTALL_DIR}/kde4/devel NO_DEFAULT_PATH )
    set(KDE4_KTEXTEDITOR_LIBS ${ktexteditor_LIB_DEPENDS} ${KDE4_KTEXTEDITOR_LIBRARY} )
 
    # Can't do that, it's not always compiled.
@@ -527,7 +527,7 @@
    find_library(KDE4_KFORMULA_LIBRARY NAMES kformula PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
    set(KDE4_KFORMULA_LIBS ${kformula_LIB_DEPENDS} ${KDE4_KFORMULA_LIBRARY} )
 
-   find_library(KDE4_PLASMA_LIBRARY NAMES plasma PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
+   find_library(KDE4_PLASMA_LIBRARY NAMES plasma PATHS ${KDE4_LIB_INSTALL_DIR}/kde4/devel NO_DEFAULT_PATH )
    set(KDE4_PLASMA_LIBS ${plasma_LIB_DEPENDS} ${KDE4_PLASMA_LIBRARY} )
 
 
@@ -540,14 +540,14 @@
 
    # at first look in LIBEXEC_INSTALL_DIR and no default paths,
    # if this didn't succeed, the second call makes cmake search again, but in the standard paths
-   find_program(KDE4_KCFGC_EXECUTABLE NAME kconfig_compiler PATHS ${KDE4_BIN_INSTALL_DIR} NO_DEFAULT_PATH )
-   find_program(KDE4_KCFGC_EXECUTABLE NAME kconfig_compiler )
+   find_program(KDE4_KCFGC_EXECUTABLE NAME kconfig_compiler4 PATHS ${KDE4_BIN_INSTALL_DIR} NO_DEFAULT_PATH )
+   find_program(KDE4_KCFGC_EXECUTABLE NAME kconfig_compiler4 )
 
    find_program(KDE4_MEINPROC_EXECUTABLE NAME meinproc4 PATHS ${KDE4_BIN_INSTALL_DIR} NO_DEFAULT_PATH )
    find_program(KDE4_MEINPROC_EXECUTABLE NAME meinproc4 )
 
-   find_program(KDE4_MAKEKDEWIDGETS_EXECUTABLE NAME makekdewidgets PATHS ${KDE4_BIN_INSTALL_DIR} NO_DEFAULT_PATH )
-   find_program(KDE4_MAKEKDEWIDGETS_EXECUTABLE NAME makekdewidgets )
+   find_program(KDE4_MAKEKDEWIDGETS_EXECUTABLE NAME makekdewidgets4 PATHS ${KDE4_BIN_INSTALL_DIR} NO_DEFAULT_PATH )
+   find_program(KDE4_MAKEKDEWIDGETS_EXECUTABLE NAME makekdewidgets4 )
 
    # allow searching cmake modules in all given kde install locations (KDEDIRS based)
    execute_process(COMMAND "${KDE4_KDECONFIG_EXECUTABLE}" --path data OUTPUT_VARIABLE _data_DIR ERROR_QUIET OUTPUT_STRIP_TRAILING_WHITESPACE)
@@ -584,14 +584,14 @@
 
 # # This option enables the reduced link interface for libs on UNIX
 # #
-# # The purpose of the KDE4_DISABLE_PROPERTY_ variable is to be used as a prefix for 
+# # The purpose of the KDE4_DISABLE_PROPERTY_ variable is to be used as a prefix for
 # # the target property LINK_INTERFACE_LIBRARIES. If it is empty, the property will have its
 # # correct name, if it's not empty, it will be a different name, i.e. the actual property
 # # will not be set, i.e. disabled. See kdelibs/kdecore/CMakeLists.txt for an example.
 # #
-# # By default (i.e. also for Windows) make it non-empty, so the property name will 
-# # change from "LINK_INTERFACE_LIBRARIES" to "DISABLED_LINK_INTERFACE_LIBRARIES", 
-# # which is a different (non-existing) target property, and so setting that property 
+# # By default (i.e. also for Windows) make it non-empty, so the property name will
+# # change from "LINK_INTERFACE_LIBRARIES" to "DISABLED_LINK_INTERFACE_LIBRARIES",
+# # which is a different (non-existing) target property, and so setting that property
 # # won't have an effect
 
 # disable this for now for Windows, since there is an issue with the use of "debug" and
@@ -600,7 +600,7 @@
 # disable the reduced linking temporarily for Windows, cmake HEAD and the soon-to-be-released cmake 2.6.2
 # With 2.6.0 and 2.6.1 it can happen that the "debug", "optimized" and "general" keywords are
 # misinterpreted by cmake as library names, the linking fails. Usually this happens under Windows.
-# In 2.6.2 this will be an error at cmake time, so we disable it for now and once we require 
+# In 2.6.2 this will be an error at cmake time, so we disable it for now and once we require
 # 2.6.2 we'll fix it the right way (using TARGET_LINK_LIBRARIES(foo LINK_INTERFACE_LIBRARIES ...)
 if (WIN32  OR  "${CMAKE_MINOR_VERSION}" EQUAL 7  OR  "${CMAKE_PATCH_VERSION}" EQUAL 2)
    set(KDE4_DISABLE_PROPERTY_ "DISABLED_")
@@ -761,7 +761,7 @@
 
 # The INSTALL_TARGETS_DEFAULT_ARGS variable should be used when libraries are installed.
 # The arguments are also ok for regular executables, i.e. executables which don't go
-# into sbin/ or libexec/, but for installing executables the basic syntax 
+# into sbin/ or libexec/, but for installing executables the basic syntax
 # INSTALL(TARGETS kate DESTINATION "${BIN_INSTALL_DIR}")
 # is enough, so using this variable there doesn't help a lot.
 # The variable must not be used for installing plugins.
@@ -771,7 +771,7 @@
 # This will install libraries correctly under UNIX, OSX and Windows (i.e. dll's go
 # into bin/.
 # Later on it will be possible to extend this for installing OSX frameworks
-# The COMPONENT Devel argument has the effect that static libraries belong to the 
+# The COMPONENT Devel argument has the effect that static libraries belong to the
 # "Devel" install component. If we use this also for all install() commands
 # for header files, it will be possible to install
 #   -everything: make install OR cmake -P cmake_install.cmake
@@ -803,13 +803,14 @@
 set(CMAKE_SYSTEM_PROGRAM_PATH ${CMAKE_SYSTEM_PROGRAM_PATH}
                               "${KDE4_BIN_INSTALL_DIR}" )
 
-set(CMAKE_SYSTEM_LIBRARY_PATH ${CMAKE_SYSTEM_LIBRARY_PATH} 
+set(CMAKE_SYSTEM_LIBRARY_PATH "${KDE4_LIB_INSTALL_DIR}/kde4/devel"
+                              ${CMAKE_SYSTEM_LIBRARY_PATH}
                               "${KDE4_LIB_INSTALL_DIR}" )
 
 # under Windows dlls may be also installed in bin/
 if(WIN32)
-  set(CMAKE_SYSTEM_LIBRARY_PATH ${CMAKE_SYSTEM_LIBRARY_PATH} 
-                                "${_CMAKE_INSTALL_DIR}/bin" 
+  set(CMAKE_SYSTEM_LIBRARY_PATH ${CMAKE_SYSTEM_LIBRARY_PATH}
+                                "${_CMAKE_INSTALL_DIR}/bin"
                                 "${CMAKE_INSTALL_PREFIX}/bin" )
 endif(WIN32)
 
@@ -834,8 +835,8 @@
 
    find_package(KDEWIN32 REQUIRED)
 
-   # limit win32 packaging to kdelibs at now 
-   # don't know if package name, version and notes are always available 
+   # limit win32 packaging to kdelibs at now
+   # don't know if package name, version and notes are always available
    if(_kdeBootStrapping)
       find_package(KDEWIN_Packager)
       if (KDEWIN_PACKAGER_FOUND)
@@ -1198,9 +1199,9 @@
    endif (NOT _kdeBootStrapping)
 
    if(KDE4_KCFGC_EXECUTABLE)
-      message(STATUS "Found KDE4 kconfig_compiler preprocessor: ${KDE4_KCFGC_EXECUTABLE}")
+      message(STATUS "Found KDE4 kconfig_compiler4 preprocessor: ${KDE4_KCFGC_EXECUTABLE}")
    else(KDE4_KCFGC_EXECUTABLE)
-      message(STATUS "Didn't find the KDE4 kconfig_compiler preprocessor")
+      message(STATUS "Didn't find the KDE4 kconfig_compiler4 preprocessor")
    endif(KDE4_KCFGC_EXECUTABLE)
 
    if(AUTOMOC4_EXECUTABLE)
@@ -1241,7 +1242,7 @@
    ${KDE4_INCLUDE_DIR}/KDE
    ${KDE4_PHONON_INCLUDES}
    ${QT_INCLUDES}
-   ${_KDE4_PLATFORM_INCLUDE_DIRS} 
+   ${_KDE4_PLATFORM_INCLUDE_DIRS}
 )
 
 set(KDE4_DEFINITIONS ${_KDE4_PLATFORM_DEFINITIONS} -DQT_NO_STL -DQT_NO_CAST_TO_ASCII -D_REENTRANT -DKDE_DEPRECATED_WARNINGS )
@@ -128,7 +128,7 @@
 #
 #  KDE4_ADD_WIDGET_FILES (SRCS_VAR file1.widgets ... fileN.widgets)
-#    Use this to add widget description files for the makekdewidgets code generator
+#    Use this to add widget description files for the makekdewidgets4 code generator
 #    for Qt Designer plugins.
 #